Checks what columns in an alignment have ambiguous bases or missing data.
Usage
is.ambig(DNAbin)
Arguments
DNAbin
A DNA alignment of class `DNAbin'.
Value
A logical vector containing TRUE if ambiguous bases or missing data are present, FALSE if not. Does not differentiate between the two classes of data.
Details
Ambiguous bases are bases that have been coded with any of the Union of Pure and Applied Chemistry (IUPAC) DNA codes that are not A, C, G, or T. Missing data are bases that have been coded with "-", "?" or "N".