Learn R Programming

spider (version 1.2-0)

nucDiag: Nucleotide diagnostics for species alignments

Description

Determines the diagnostic nucleotides for each species given in sppVector.

Usage

nucDiag(DNAbin, sppVector)

Arguments

DNAbin
An object of class 'DNAbin'.
sppVector
The species vector (see sppVector).

Value

  • A list giving the pure, simple diagnostic nucleotides (i.e. those nucleotides that are fixed within species and different from all other species) for each species in the species vector. A result of integer(0) indicates there are no diagnostic nucleotides for those species.

References

Sarkar, I., Planet, P., & DeSalle, R. (2008). CAOS software for use in character- based DNA barcoding. _Molecular Ecology Resources_ *8* 1256-1259

See Also

slideNucDiag

Examples

Run this code
data(anoteropsis)
anoSpp <- sapply(strsplit(dimnames(anoteropsis)[[1]], split="_"), 
	function(x) paste(x[1], x[2], sep="_"))

nucDiag(anoteropsis, anoSpp)

#To view the nucleotide values 
anoNuc <- nucDiag(anoteropsis, anoSpp)
as.character(anoteropsis[ ,anoNuc[[1]][1] ])



data(sarkar)
sarkarSpp <- substr(dimnames(sarkar)[[1]], 1, 3)
nucDiag(sarkar, sarkarSpp)

Run the code above in your browser using DataLab