tajima.K: Calculate Tajima's K index of divergence
Description
Calculates Tajima's K index of divergence.
Usage
tajima.K(DNAbin, prop = TRUE)
Arguments
DNAbin
An object of class `DNAbin'.
prop
Logical. Should the function report the number of substitutions per nucleotide? Default of TRUE.
Value
A vector of length 1. If prop = FALSE, the mean number of substitutions between any two sequences is returned. If prop = TRUE (the default), this number is returned as the mean number of substitutions per nucleotide (i.e. the above divided by the length of the sequences).
References
Tajima, F. (1983). Evolutionary relationship of DNA sequences in finite
populations. _Genetics_ *105*, 437-460.